@@ -22,4 +22,18 @@ my $som = $soap->wsdl("file:///$path/wsdl/globalweather.xml")
 
 die $som->message() if $som->fault();
 
-print $som->result();
\ No newline at end of file
+print $som->result();
+
+
+# SOAP::Lite variant:
+
+use SOAP::Lite;
+my $soap = SOAP::Lite->new()->on_action( sub { join'/', @_ } )
+  ->proxy("http://www.webservicex.net/globalweather.asmx");
+my $som = $soap->call(
+    SOAP::Data->name('GetWeather')->attr({ xmlns => 'http://www.webserviceX.NET' }), 
+    SOAP::Data->name('CountryName')->value('Germany'), 
+    SOAP::Data->name('CityName')->value('Munich') 
+);
+
+print $som->result();
