@@ -28,8 +28,7 @@ sub _initialize {
     my $current = undef;
     my $ignore = [ 'Envelope', 'Body' ];        # top level elements to ignore
     my $list = [];                              # node list
-    my $path = [];                              # current path (without 
-                                                # number)     
+    my $path = [];                              # current path 
     my $skip = 0;                               # skip elements
 
     # use "globals" for speed
@@ -84,7 +83,7 @@ sub _initialize {
             $current = $_class->new({ %_attrs });   # set new current object
         
             # remember top level element
-            defined $self->{ data } 
+            exists $self->{ data } 
                 or ($self->{ data } = $current); 
         },
         
@@ -143,6 +142,13 @@ sub parsefile {
     return $_[0]->{ data };     
 }
 
+# SAX-like aliases
+sub parse_string;
+*parse_string = \&parse;
+
+sub parse_file;
+*parse_file = \&parsefile;
+
 sub get_data {
     return $_[0]->{ data };
 }
@@ -202,9 +208,9 @@ This module may be used under the same terms as perl itself.
 
  $ID: $
 
- $LastChangedDate: $
- $LastChangedRevision: $
- $LastChangedBy: $
+ $LastChangedDate: 2007-08-31 17:28:29 +0200 (Fr, 31 Aug 2007) $
+ $LastChangedRevision: 176 $
+ $LastChangedBy: kutterma $
 
- $HeadURL: $
+ $HeadURL: https://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/Expat/MessageParser.pm $
 
